==> lambda-vue-3.0.94.tgz: package/src/modules/datagrid/utils/agMN.js <==
export const localeText = {

    // for filter panel
    page: 'Хуудас',
    more: 'Дэлгэрэнгүй',
    to: 'хүртэл',
    of: 'Of',
    next: 'Дараах',
    last: 'Сүүлийн',
    first: 'Эхний',
    previous: 'Өмнөх',
    loadingOoo: 'Ачаалж байна...',

    // for set filter
    selectAll: 'Бүгдийг сонгох',
    searchOoo: 'Хайх...',
    blanks: 'Хоосон',

    // for number filter and text filter
    filterOoo: 'Шүүх...',
    applyFilter: 'Шүүж харах',
    clearFilter: 'Цэвэрлэх',

    // for number filter
    equals: 'Тэнцүү',
    notEqual: 'Тэнцүү биш',
    inRange: 'Хооронд',
    lessThan: 'бага',
    lessThanOrEqual: 'тэнцүү эсвэл бага',
    greaterThan: 'их',
    greaterThanOrEqual: 'тэнцүү эсвэл их',

    // for text filter
    contains: 'агуулсан',
    notContains: 'агуулаагүй',

    startsWith: 'эхэлсэн',
    endsWith: 'төгссөн',

    // the header of the default group column
    group: 'нэгтгэх',

    // tool panel
    columns: ' Талбарууд ',
    rowGroupColumns: 'нэгтгэсэн багана',
    rowGroupColumnsEmptyMessage: 'ийш нь багана чирж нэгтгэж харна',
    valueColumns: 'багананы утга',
    pivotMode: 'Пивот горим',
    groups: 'Нэгтгэлүүд',
    values: 'Утгууд',
    pivots: 'пивот',
    valueColumnsEmptyMessage: 'энд багана чирж утгуудыг нэгтгэж харна',
    pivotColumnsEmptyMessage: 'энд багана чирж пивот үүсгэж харна',
    toolPanelButton: 'la tool panel',

    // other
    noRowsToShow: 'Мэдээлэл олдсонгүй',

    // enterprise menu
    pinColumn: 'багана түгжих',
    valueAggregation: 'laValue Agg',
    autosizeThiscolumn: 'laAutosize Diz',
    autosizeAllColumns: 'laAutsoie em All',
    groupBy: 'нэгтгэх',
    ungroupBy: 'нэгтгэл болиулах',
    resetColumns: 'laReset Those Cols',
    expandAll: 'laOpen-em-up',
    collapseAll: 'laClose-em-up',
    toolPanel: 'laTool Panelo',
    export: 'экспорт',
    csvExport: ' CSV экспорт',
    excelExport: 'Excel экспорт',

    // enterprise menu pinning
    pinLeft: 'Зүүн талд түгжих <<',
    pinRight: 'Баруун талд түгжих >>',
    noPin: 'Түгжээг авах <>',

    // enterprise menu aggregation and status panel
    sum: 'Нийлбэр',
    min: 'Хамгийн бага',
    max: 'Хамгийн их',
    none: 'Утгагүй',
    count: 'Тоолох',
    average: 'Дундаж',

    // standard menu
    copy: 'Хуулах',
    copyWithHeaders: 'толгойн мэдээлэлтэй хамт хуулах',
    ctrlC: 'ctrl+C',
    paste: 'Буулгах',
    ctrlV: 'ctrl+v'
}

==> lambda-vue-3.1.97.tgz: package/src/modules/datagrid/utils/agMN.js <==
export const localeText = {

    // for filter panel
    page: 'Хуудас',
    more: 'Дэлгэрэнгүй',
    to: 'хүртэл',
    of: 'Of',
    next: 'Дараах',
    last: 'Сүүлийн',
    first: 'Эхний',
    previous: 'Өмнөх',
    loadingOoo: 'Ачаалж байна...',

    // for set filter
    selectAll: 'Бүгдийг сонгох',
    searchOoo: 'Хайх...',
    blanks: 'Хоосон',

    // for number filter and text filter
    filterOoo: 'Шүүх...',
    applyFilter: 'Шүүж харах',
    clearFilter: 'Цэвэрлэх',

    // for number filter
    equals: 'Тэнцүү',
    notEqual: 'Тэнцүү биш',
    inRange: 'Хооронд',
    lessThan: 'бага',
    lessThanOrEqual: 'тэнцүү эсвэл бага',
    greaterThan: 'их',
    greaterThanOrEqual: 'тэнцүү эсвэл их',

    // for text filter
    contains: 'агуулсан',
    notContains: 'агуулаагүй',

    startsWith: 'эхэлсэн',
    endsWith: 'төгссөн',

    // the header of the default group column
    group: 'нэгтгэх',

    // tool panel
    columns: ' Талбарууд ',
    rowGroupColumns: 'нэгтгэсэн багана',
    rowGroupColumnsEmptyMessage: 'ийш нь багана чирж нэгтгэж харна',
    valueColumns: 'багананы утга',
    pivotMode: 'Пивот горим',
    groups: 'Нэгтгэлүүд',
    values: 'Утгууд',
    pivots: 'пивот',
    valueColumnsEmptyMessage: 'энд багана чирж утгуудыг нэгтгэж харна',
    pivotColumnsEmptyMessage: 'энд багана чирж пивот үүсгэж харна',
    toolPanelButton: 'Багаж',

    // other
    noRowsToShow: 'Мэдээлэл олдсонгүй',

    // enterprise menu
    pinColumn: 'багана түгжих',
    valueAggregation: 'нэгтгэл утга',
    autosizeThiscolumn: 'Өргөн авто',
    autosizeAllColumns: 'Бүх багана өргөн авто',
    groupBy: 'нэгтгэх',
    ungroupBy: 'нэгтгэл болиулах',
    resetColumns: 'Багана шинэчлэх',
    expandAll: 'Дэлгэх',
    collapseAll: 'Хаах',
    toolPanel: 'Багаж',
    export: 'экспорт',
    csvExport: ' CSV экспорт',
    excelExport: 'Excel экспорт',

    // enterprise menu pinning
    pinLeft: 'Зүүн талд түгжих <<',
    pinRight: 'Баруун талд түгжих >>',
    noPin: 'Түгжээг авах <>',

    // enterprise menu aggregation and status panel
    sum: 'Нийлбэр',
    min: 'Хамгийн бага',
    max: 'Хамгийн их',
    none: 'Утгагүй',
    count: 'Тоолох',
    average: 'Дундаж',

    // standard menu
    copy: 'Хуулах',
    copyWithHeaders: 'толгойн мэдээлэлтэй хамт хуулах',
    ctrlC: 'ctrl+C',
    paste: 'Буулгах',
    ctrlV: 'ctrl+v'
}
